@@ -15,7 +15,8 @@ output_ls = master.call(
 	input_ls,	# 入力のリスト (ジョブごと)
 	n = 4,	# 並列数
 	job_order = "ordered",	# ジョブ実行順序 (random, ordered)
-	progress = True	# 進捗表示
+	progress = True,	# 進捗表示
+	slave_debug = False	# スレーブの標準出力の表示 (debug)
 )
 
 sout(output_ls, None)
