@@ -153,7 +153,7 @@ def call(
 	if popen_call_func is None:
 		popen_call_func = default_popen_call_func
 	# 入出力データの設置場所
-	data_dir = "%s/../__mult_temp_data__/"%slave_filename
+	data_dir = "%s/__mult_temp_data__/"%os.path.dirname(slave_filename)
 	# ジョブ識別記号
 	jid_prefix = gen_random_prefix(n = 16)	# ランダムな接頭辞の生成 (ジョブ識別記号に用いる)
 	# ジョブ投入を部分適用 (引数が多くてわかりにくいため)
